// Copyright 2023 schukai GmbH
// SPDX-License-Identifier: AGPL-3.0

package utils

import (
	"os"
	"path/filepath"
	"testing"
)

func TestMaskCodeBlocks(t *testing.T) {
	tables := []struct {
		input    string
		file     string
		count    int
		expected int
	}{
		{"/testing/assets/code1.md", "code1.md", 3, 9},
	}

	for _, table := range tables {

		p, _ := os.Getwd()
		p = filepath.Dir(p) // go to parent directory
		p = filepath.Dir(p) // go to parent directory
		p = filepath.Join(p, table.input)

		code, err := os.ReadFile(p)
		if err != nil {
			t.Errorf("Error reading file %s", table.input)
		}

		s, m := MaskCodeBlocks(string(code), table.file, table.count)

		if len(m) != table.expected {
			t.Errorf("Expected %d code blocks, got %d", table.expected, len(m))
		}

		if s == string(code) {
			t.Errorf("Expected %s, got %s", string(code), s)
		}

	}
}

func TestSubstring(t *testing.T) {
	tables := []struct {
		input    string
		start    int
		length   int
		expected string
	}{
		{"abcdefg", 0, 0, ""},
		{"abcdefg", 0, 1, "a"},
		{"abcdefg", 0, 2, "ab"},
		{"abcdefg", 0, 3, "abc"},
		{"abcdefg", 0, 4, "abcd"},
		{"abcdefg", 0, 5, "abcde"},
		{"abcdefg", 0, 6, "abcdef"},
		{"abcdefg", 0, 7, "abcdefg"},
		{"abcdefg", 0, 8, "abcdefg"},
		{"abcdefg", 0, 9, "abcdefg"},
		{"abcdefg", 1, 6, "bcdefg"},

		{"abcdefg", 3, 6, "defg"},
		{"abcdefg", 3, 5, "defg"},
		{"abcdefg", 3, 4, "defg"},
		{"abcdefg", 3, 3, "def"},
		{"abcdefg", 3, 2, "de"},
		{"abcdefg", 3, 1, "d"},
		{"abcdefg", 3, 0, ""},
	} // end of tables
	for _, table := range tables {
		actual := Substring(table.input, table.start, table.length)
		if actual != table.expected {
			t.Errorf("Substring(%s, %d, %d) = %s, expected %s", table.input, table.start, table.length, actual, table.expected)
		}
	}
}
